from django.apps import AppConfig


class ModelCloneConfig(AppConfig):
    name = "model_clone"
